
[![PyPI](https://img.shields.io/pypi/v/lynxinven)](https://pypi.org/j9FPZ_4YCUdxkf_m/project/lynxinven/)
![Build Status](https://github.com/Lynx-Solve/LynxInven_PIP/ci.yaml/badge.svg)
[![Coverage Status](https://coveralls.io/repos/github/Lynx-Solve/lynxinven-python/badge.svg)](https://coveralls.io/github/Lynx-Solve/lynxinven-python)
![PEP](https://github.com/Lynx-Solve/LynxInven_PIP/pep.yaml/badge.svg)

## LynxInven Python Interface

Python library for communication with the [LynxInven parts management system](https:///github.com/Lynx-Solve/lynxinven) using the integrated REST API.

This library provides a class-based interface for interacting with the database. Each database table is represented as a class object which provides features analogous to the REST CRUD endpoints (Create, Retrieve, Update, Destroy).

## Installation (Inventory PIP Install)

The LynxInven python library can be easily installed using PIP:

```
pip install lynxinven
```

@Eric to test Reload
